@@ -1,7 +1,7 @@
 ft_gradientCasM <-
 function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
                    {
-                    # Arguments specifiques ‡ la fonction
+                    # Arguments specifiques  la fonction
                     # d: vecteur des proportion de cas et de temoins echantillonnes 
                     # gmname: nom de la variable contenant le genotype de la mere
                     # gcname: nom de la variable contenant le genotype de l enfant
@@ -10,10 +10,10 @@ function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
                     
                     # creation de deux table une avec tous les donnees complet de c et l autre avec les seules c observables
                       lstdat<-fctcd(data1,gcname,yname)
-                      datMod<-lstdat$datdmcp # data des données complets (tout ijm * 3)
-                      datNo<-lstdat$datnmv # data complet c'est-à-dire pour chaque patient nous avons ijmc
-                      datMv<-lstdat$datdm  # data complété c'est à dire pour chaque coupe ijm on donne toutes les combi de c
-                      datrmv<-lstdat$datmv # data de donnée manquantes 
+                      datMod<-lstdat$datdmcp # data des donnees complets (tout ijm * 3)
+                      datNo<-lstdat$datnmv # data complet c'est-a-dire pour chaque patient nous avons ijmc
+                      datMv<-lstdat$datdm  # data complete c'est a dire pour chaque coupe ijm on donne toutes les combi de c
+                      datrmv<-lstdat$datmv # data de donnee manquantes 
 
 					# Nom des variables
                       varz00<-all.vars(fl)
@@ -58,13 +58,13 @@ function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
                       pp<-length(vecma.u)/2;ppd<-2*pp;uu<-pp+1
                       ma.u<-rbind(vecma.u[1:pp],vecma.u[uu:ppd])
 
-					# Données de tous les sujets                      
+					# Donnees de tous les sujets                      
                       vxt = rbind(vx,vxb)
                     # Extraction du vecteur de genotypes de la mere
                       gmt <- vxt[,gmname]
                     # Extraction du vecteur de genotypes de lenfant
                       gct <- vxt[,gcname]
-                    # Vecteur de réponse
+                    # Vecteur de reponse
                       outct = c(outc,outcb)
                       
                     # 2-Construction du systeme non lineaire =======================================
@@ -105,30 +105,30 @@ function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
                                     # A-nv
                                     # prob conditionel de l'enf sachant la mere Pc/m matd
                                     Pgcm<-Prgcm_HW1(matd[,c(gmname,gcname)],theta.start)
-                                    # Dérivée de la prob conditionel de l'enf sachant la mere                                    
+                                    # Derivee de la prob conditionel de l'enf sachant la mere                                    
                                     dPgcm.theta<-dPrgcm_HW1.theta(matd[,c(gmname,gcname)],theta.start)
                                     dlogPgcm.theta<-dlogPrgcm_HW1.theta(matd[,c(gmname,gcname)],theta.start)
                                                                      
                                     # calcul du genotype 
                                     Pgm<-Prgm_HW1(matd[,gmname],theta.start)
-                                    # calcul de sa dérivée
+                                    # calcul de sa derivee
                                     dPgm.theta<-dPrgm_HW1.theta(matd[,gmname],theta.start)
 
                                     # B-nv
                                     # prob conditionel de l enf sachant la mere Pc/m matd
                                     Pgcmb<-Prgcm_HW1(matdb[,c(gmname,gcname)],theta.start)
-                                    # Dérivée de la prob conditionel de l'enf sachant la mere                                    
+                                    # Derivee de la prob conditionel de l'enf sachant la mere                                    
                                     dPgcmb.theta<-dPrgcm_HW1.theta(matdb[,c(gmname,gcname)],theta.start)
                                                                      
                                     # calcul du genotype 
                                     Pgmb<-Prgm_HW1(matdb[,gmname],theta.start)
-                                    # calcul de sa dérivée
+                                    # calcul de sa derivee
                                     dPgmb.theta<-dPrgm_HW1.theta(matdb[,gmname],theta.start)
                                     
                                                                                                             
                                     # A-calcul de la fonction hijmc 
                                     Hijmc<-Pijmc*Pgcm
-                                    # calcul des dérivées de la fonction hijmc                                    
+                                    # calcul des derivees de la fonction hijmc                                    
                                     dHijmc.eta<-dPijmc.eta * Pgcm
                                     dHijmc.theta<-Pijmc * dPgcm.theta   
                                     
@@ -136,10 +136,10 @@ function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
 
                                     # B-calcul de la fonction hijmc 
                                     Hijmcb<-Pijmcb*Pgcmb
-                                    # calcul des dérivées de la fonction hijmc                                    
+                                    # calcul des derivees de la fonction hijmc                                    
                                     dHijmcb.eta<-dPijmcb.eta * Pgcmb
                                     dHijmcb.theta<-Pijmcb * dPgcmb.theta   
-                                    # Multiplication des termes de dérivée à sommer par la matrix de design    
+                                    # Multiplication des termes de derivee a sommer par la matrix de design    
                                     mat.dHijmcb = vxb*dHijmcb.eta    
                                     colnames(mat.dHijmcb) = paste("dHijmcb.",colnames(vxb),sep="") 
                                     
@@ -152,7 +152,7 @@ function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
                                     names(matA.comp0)<-nam;
 
                                     #B-data.frame 
-                                    # On crée ces noms à l'avance
+                                    # On cree ces noms a l'avance
                                     dHijmc.names = paste("dHijmc.",colnames(vx),sep="") 
                                     dHijm.names = paste("dHijm.",colnames(vx),sep="") 
                                     
@@ -207,7 +207,7 @@ function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
                                     mat.Hijmc<-mat.Hijmc1[mat.Hijmc1[,"Hijmc"]!=0,]
                                     # Somme sur c de Hijmc
                                     mat.Hijm<-fpol1(mat.Hijmc,c("outc",varz,gmname,"Pgm"),"Hijmc","Hijm","dPgm.theta")
-                                    # Multiplication des termes de dérivée à sommer par la matrix de design    
+                                    # Multiplication des termes de derivee a sommer par la matrix de design    
                                     mat.Hijmc[,dHijmc.names] = mat.Hijmc[,colnames(vx)]*mat.Hijmc$dHijmc.eta                                    
                                     # Somme sur c de dHijmc.beta
                                     mat.dHijm.beta<-fpolm(mat.Hijmc,c("outc",varz,gmname,"Pgm"),dHijmc.names,dHijm.names)
@@ -242,7 +242,7 @@ function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
                                       
                                     tab.cjm<-merge(mat.cjm,mat.fjm,by=c(varz,gmname))
                                     qjm<-tab.cjm$Cjm/tab.cjm$Fjm
-                                    # termes de dérivée à sommer sur j pour obtenir dNm.beta et dNm.theta
+                                    # termes de derivee a sommer sur j pour obtenir dNm.beta et dNm.theta
                                     djm.beta<-(-tab.cjm$Cjm/tab.cjm$Fjm^2)*tab.cjm[,dFjm.names]                                    
                                     djm.theta<-(-tab.cjm$Cjm/tab.cjm$Fjm^2)*tab.cjm$dFjm.theta
                                
@@ -298,7 +298,7 @@ function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
                                     # nv 
                         			mat.Zim<-fpol1(tab.Zijm,c("outc",gmname),"Zijm","Zim")
                         			dg312.names = paste("dg312.",colnames(vx),sep="")
-                        			# Attention! Ici, pour une raison inexpliquée, il faut que c(gmname,"outc") soient dans cet ordre pour un résultat correct                                                                        
+                        			# Attention Ici, pour une raison inexpliquee, il faut que c(gmname,"outc") soient dans cet ordre pour un resultat correct                                                                        
                         			mat.dg312<-fpolm(tab.dg312,c(gmname,"outc"),c(names(dg312j.beta),"dg312j.theta"),c(dg312.names,"dg312.theta"))
                         			
 			
@@ -319,7 +319,7 @@ function(fl,data1,N,gmname,gcname,yname,vecma.u,HW=TRUE)
                                     
                                     tmp = merge(tab.wim,mat.dg312,by=c("outc",gmname))                                     
                                     mat.dg31 = merge(tmp,mat.dg311,by=gmname)
-                                    # Attention! En sommant les variables dg311.beta et dg312.names, le résultat garde les noms dg311.beta                                  
+                                    # Attention En sommant les variables dg311.beta et dg312.names, le resultat garde les noms dg311.beta                                  
                                     dg31.beta = mat.dg31[,names(dg311.beta)]*mat.dg31$Zim + mat.dg31$Rm*mat.dg31[,dg312.names]
                                     dg31.theta = mat.dg31$dg311.theta*mat.dg31$Zim + mat.dg31$Rm*mat.dg31$dg312.theta                                    
 
